"""gdi-admin URL Configuration

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/4.0/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  path('', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  path('', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.urls import include, path
    2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
"""
from django.contrib import admin
from django.urls import include, path, re_path

from main import views, sta_views
from main.about import basic_site

urlpatterns = [
    path('gdi-backend/admin/', admin.site.urls),
    path('gdi-backend/about/', basic_site.admin_view(basic_site.about), name='about'),
    path('gdi-backend/download/<file_identifier>', views.get_download, name='download'),
    path('gdi-backend/download/zip/<file_identifier>', views.get_zip_download, name='zipDownload'),
    path('gdi-backend/countries', views.get_countries, name='countries'),
    re_path(r'^gdi-backend/proxy', views.proxy_geoserver_request, name='proxy'),
    path('gdi-backend/sta-locations/<int:sta_endpoint_id>/<int:obs_property_id>', sta_views.proxy_sta_locations, name='sta-locations-by-observed-property'),
    path('gdi-backend/sta-locations/<int:sta_endpoint_id>', sta_views.proxy_sta_locations, name='sta-locations'),
    path('gdi-backend/sta-obs-properties/<int:sta_endpoint_id>', sta_views.proxy_sta_obs_properties, name='sta-obs-properties'),
    path('gdi-backend/sta-obs-properties-by-thing/<int:sta_endpoint_id>/<int:thing_id>', sta_views.proxy_sta_obs_properties_by_thing, name='sta-obs-properties-by-thing'),
    path('gdi-backend/sta-all-datastreams/<int:sta_endpoint_id>/<int:thing_id>/<int:obs_property_id>', sta_views.proxy_sta_all_datastreams, name='sta-all-datastreams'),
    path('gdi-backend/sta-datastream/<int:sta_endpoint_id>/<int:thing_id>/<int:datastream_id>', sta_views.proxy_sta_datastream, name='sta-datastream'),
    re_path(r'^gdi-backend/process', views.call_process, name='aggregation'),
    re_path(r'^gdi-backend/districts/(?P<country_id>[0-9][0-9])$', views.get_districts_by_country, name='districts'),
    path('gdi-backend/uncertainty/<path:file_path>', views.get_uncertainty, name='uncertainty'),
    re_path(r'^gdi-backend/project/(?P<locale>[a-z]{2})/(?P<project_name>[a-z0-9-]*)$', views.get_project_information, name='getProjectInformation'),
    re_path(r'^gdi-backend/projects/(?P<locale>[a-z]{2})', views.get_projects, name='getProjects'),
    re_path(r'^gdi-backend/areas/(?P<locale>[a-z]{2})/(?P<project_name>[a-z0-9-]*)$', views.get_project_areas, name='getProjectAreas'),
    path('gdi-backend/filter/<str:locale>/<int:area_id>', views.get_filters, name='getProjectFilters'),
    re_path(r'^_nested_admin/', include('nested_admin.urls')),
]

admin.site.enable_nav_sidebar = False
