from django.contrib import admin

from main.models import Area, AreaLayer, Bucket, Project
from main.lib.utils.backend import get_user_groups


class AreaFilter(admin.SimpleListFilter):
    title = 'Areas'
    parameter_name = 'area_layer'

    def lookups(self, request, model_admin):
        result = []
        if request.user.is_superuser:
            areas = Area.objects.all()
        else:
            areas = Area.objects.filter(project__bucket__group__in=get_user_groups(request))

        for area in areas:
            result.append((area.id, area.name_de))

        result.append((0, 'None'))

        return result

    def queryset(self, request, query_set):

        if self.value():
            if int(self.value()) == 0:
                return query_set.filter(arealayer__area_id__isnull=True)

        if self.value():
            print(self.value())
            return query_set.filter(arealayer__area=self.value())
        else:
            return query_set


class AreaLayerInline(admin.TabularInline):
    model = AreaLayer
    fieldsets = [
        (None, {
            'fields': ('area', 'position', 'is_active', 'is_default_on_start', ),
        }),
    ]
    min_num = 1
    max_num = 1
    extra = 0

    def formfield_for_foreignkey(self, db_field, request, **kwargs):

        if not request.user.is_superuser:
            # if not superuser, a user can only select areas from his projects
            if db_field.name == "area":
                projects = Project.objects.filter(bucket__group__in=get_user_groups(request))

                kwargs["queryset"] = Area.objects.filter(project__in=projects)

        return super().formfield_for_foreignkey(db_field, request, **kwargs)
