from django.contrib import admin

from main.models import AreaLayer, Bucket, FileRecord, GeojsonLayer
from main.forms.layer.area_layer import AreaFilter, AreaLayerInline

from main.lib.utils.backend import get_user_groups


class GeojsonLayerAdmin(admin.ModelAdmin):
    model = GeojsonLayer
    inlines = [AreaLayerInline]
    list_display = ('__str__', 'file_record', 'get_position', 'get_is_active', 'get_is_default')
    list_filter = (AreaFilter,)
    save_as = True

    fieldsets = [
        (None, {
            'fields': (('name_de', 'name_en'), 'file_record', 'geonetwork_uuid' ),
        }),
        ('optional', {
            'fields': (('info_de', 'info_en'), ),
            'classes': ('collapse',),
        })
    ]

    @admin.display(description='is active')
    def get_is_active(self, obj):
        area_layer = AreaLayer.objects.get(geojson_layer=obj)
        if area_layer:
            return area_layer.is_active
        return False

    @admin.display(description='is default')
    def get_is_default(self, obj):
        area_layer = AreaLayer.objects.get(geojson_layer=obj)
        if area_layer:
            return area_layer.is_default_on_start
        return False

    @admin.display(description='position')
    def get_position(self, obj):
        area_layer = AreaLayer.objects.get(geojson_layer=obj)
        if area_layer:
            return area_layer.position
        return False

    def get_readonly_fields(self, request, obj):
        return ['geonetwork_uuid']

    def get_queryset(self, request):
        # if not superuser, a user can see only see geojson-layers from his buckets
        qs = super().get_queryset(request)

        if request.user.is_superuser:
            return qs
        return qs.filter(file_record__bucket__group__in=get_user_groups(request))

    def formfield_for_foreignkey(self, db_field, request, **kwargs):

        if not request.user.is_superuser:
            # if not superuser, a user can only select file-records from his buckets
            if db_field.name == "file_record":
                kwargs["queryset"] = FileRecord.objects.filter(bucket__group__in=get_user_groups(request))

        return super().formfield_for_foreignkey(db_field, request, **kwargs)