from django.contrib import admin

from main.models import AreaLayer, Bucket, StaLayer
from main.forms.layer.area_layer import AreaFilter, AreaLayerInline

from main.lib.utils.backend import get_user_groups


class StaLayerAdmin(admin.ModelAdmin):
    model = StaLayer
    inlines = [AreaLayerInline]
    list_display = ('__str__', 'get_position', 'get_is_active', 'get_is_default')
    list_filter = (AreaFilter,)
    save_as = True

    fieldsets = [
        (None, {
            'fields': (('name_de', 'name_en'), 'endpoint', 'observed_property_use_group', 'legend', 'geonetwork_uuid' ),
        }),
        ('optional', {
            'fields': (('info_de', 'info_en'), ('y_axis_min', 'y_axis_max'), 'time_format', ),
            'classes': ('collapse',),
        })
    ]

    @admin.display(description='is active')
    def get_is_active(self, obj):
        area_layer = AreaLayer.objects.get(sta_layer=obj)
        if area_layer:
            return area_layer.is_active
        return False

    @admin.display(description='is default')
    def get_is_default(self, obj):
        area_layer = AreaLayer.objects.get(sta_layer=obj)
        if area_layer:
            return area_layer.is_default_on_start
        return False

    @admin.display(description='position')
    def get_position(self, obj):
        area_layer = AreaLayer.objects.get(sta_layer=obj)
        if area_layer:
            return area_layer.position
        return False

    def get_readonly_fields(self, request, obj):
        return ['geonetwork_uuid']

    def get_queryset(self, request):
        # if not superuser, a user can see only see sta-layers from his groups
        qs = super().get_queryset(request)

        if request.user.is_superuser:
            return qs
        return qs.filter(endpoint__group__in=get_user_groups(request))
