import json
import requests
from requests.auth import HTTPBasicAuth


class GeonetworkApi:

    def __init__(self, url, username, password):
        self.session = requests.Session()
        self.base_url = url
        self.auth = HTTPBasicAuth(username, password)

        # set cookie for XSRF protection
        self.session.post('{}eng/info?type=me'.format(self.base_url))

        cookie = self.session.cookies.get_dict()
        self.headers = {
            'accept': 'application/json',
            "X-XSRF-TOKEN": cookie["XSRF-TOKEN"]
        }
        self.session.post('{}srv/eng/info?type=me'.format(self.base_url), headers=self.headers, auth=self.auth)

        self.job_status = 0
        self.logs = []

    def log(self, log):
        self.logs.append(str(log))

    def set_error_status(self):
        self.job_status = 1

    def reset(self):
        self.job_status = 0
        self.logs = []

    def create_record(self, xml, geonetwork_group):
        return self._make_api_request(xml, geonetwork_group, "NOTHING")

    def update_record(self, xml, geonetwork_group):
        return self._make_api_request(xml, geonetwork_group, "OVERWRITE")

    def _make_api_request(self, xml, geonetwork_group, uuid_processing):
        self.headers['Content-Type'] = "application/xml"

        url = '{}api/0.1/records?metadataType=METADATA&recursiveSearch=false&publishToAll=false&assignToCatalog=true&uuidProcessing={}&rejectIfInvalid=false&transformWith=_none_&group={}'

        if geonetwork_group:
            response = self.session.put(
                url.format(self.base_url, uuid_processing, geonetwork_group),
                headers=self.headers,
                data=xml,
                auth=self.auth
            )

            print(response.content)

            result = json.loads(response.content)
            if "metadataInfos" in result:
                metadata = result["metadataInfos"]
                key = list(metadata.keys())[0]
                content = metadata[key][0]

                return content["uuid"]
            else:
                print('request to Geonetwork failed')
                return None

        return None

    def delete_record(self, uuid):
        delete_url = "{}api/0.1/records?uuids={}&withBackup=false".format(self.base_url, uuid)

        response = self.session.delete(delete_url, headers=self.headers, auth=self.auth)
