import json
import pytz
from datetime import datetime


class JsonParser:

    def __init__(self, fs):
        self.fs = fs

        self.data = []
        self.dimensions = []
        self.data_vars = []
        self.variables = []
        self.nc_header_data = []
        self.institution = ""
        self.originator = ""
        self.contact = ""
        self.title = ""
        self.source = ""
        self.creation_date = ""
        self.crs = ""
        self.convention = ""

    def parse(self, relative_path):
        try:

            with self.fs.open(relative_path, 'rb') as json_file:

                file = json.load(json_file)

                if 'data' in file:
                    self.data = file['data']
                if 'dimensions' in file:
                    self.dimensions = file['dimensions']
                if 'data_vars' in file:
                    self.data_vars = file['data_vars']
                if 'variables' in file:
                    self.variables = file['variables']
                if 'institution' in file:
                    self.institution = file['institution']
                if 'originator' in file:
                    self.originator = file['originator']
                if 'contact' in file:
                    self.contact = file['contact']
                if 'title' in file:
                    self.title = file['title']
                if 'source' in file:
                    self.source = file['source']
                if 'creation_date' in file:
                    self.creation_date = file['creation_date']
                if 'crs' in file:
                    self.crs = file['crs']
                if 'convention' in file:
                    self.convention = file['convention']
                if 'additional' in file:
                    self.nc_header_data = file['additional']

        except Exception as e:
            self.nc_header_data.append("could not read header from netcdf: {}".format(e))

    @staticmethod
    def get_time():
        local_timezone = pytz.timezone('Europe/Berlin')

        local_time = datetime.now(local_timezone)

        return str(local_time.strftime('%Y-%m-%d %H:%M'))
