import os
from jinja2 import Template


class MetadataService:

    def __init__(self, parser):
        self.parser = parser

    def create_xml(self, bucket, object_key, layer_file_identifier, uuid=None):

        with open(os.path.dirname(__file__) + '/geonetwork_template.xml', encoding='utf-8') as template:
            template = Template(template.read())

        return template.render(
            uuid=uuid,
            originator=self.parser.originator,
            institution=self.parser.institution,
            email=self.parser.contact,
            crs=self.parser.crs,
            epsg_code=self.get_crs(),
            dataset_name=self.get_dataset_name(object_key),
            creation_date=self.parser.creation_date,
            description=self.parser.source,
            bucket_name=bucket,
            distribution_info=self.get_convention(),
            layer_file_identifier=layer_file_identifier,
            download_url=os.environ.get('BACKEND_URL') + '/download/' + layer_file_identifier,
            lineage=self.create_lineage()
        )

    def get_crs(self):
        if self.parser.crs == "":
            return ""

        code = self.parser.crs.replace("EPSG:", "")
        code = code.replace("ESPG:", "")
        return code

    def get_dataset_name(self, object_key):
        title = self.parser.title
        if title == "":
            return object_key
        return self.encode_text(title)

    def get_convention(self):
        if self.parser.convention == "":
            return "unknown"
        return self.parser.convention

    def create_lineage(self):
        result = "Dimensionen:\n"
        for dim in self.parser.dimensions:
            result += "&#8226; " + dim + "\n"

        result += "\nVariablen:\n"
        for var in self.parser.variables:
            result += "&#8226; " + var + "\n"

        result += "\nAttribute:\n"
        for attr in self.parser.nc_header_data:
            result += "&#8226; " + attr + "\n"

        result = result.replace("\n", "&#xA;")
        return self.encode_text(result)

    @staticmethod
    def encode_text(text):
        # TODO: use Template Engine (Django Jinja2) to improve inserting of strings with special chars
        return text.replace("Δ", "&#916;")
