import xarray as xr
import pytz
from datetime import datetime


class NetcdfParser:

    def __init__(self, fs):
        self.fs = fs

        self.dimensions = []
        self.data_vars = []
        self.variables = []
        self.nc_header_data = []
        self.institution = ""
        self.originator = ""
        self.contact = ""
        self.title = ""
        self.source = ""
        self.creation_date = ""
        self.crs = ""
        self.convention = ""

    def parse(self, relative_path):
        try:

            with self.fs.open(relative_path, 'rb') as netcdf_file:

                file = xr.open_dataset(netcdf_file, engine='h5netcdf')

                for k, v in file.dims.items():
                    self.dimensions.append("{}: {}".format(k, v))

                for k, v in file.data_vars.items():
                    self.variables.append(k)

                for k, v in file.attrs.items():
                    if k == "institution":
                        self.institution = v
                        continue
                    if k == "originator":
                        self.originator = v
                        continue
                    if k == "contact":
                        self.contact = v
                        continue
                    if k == "title":
                        self.title = v
                        continue
                    if k == "source":
                        self.source = v
                        continue
                    if k == "creation_date":
                        self.creation_date = v
                        continue
                    if k == "crs":
                        self.crs = v
                        continue
                    if k == "Conventions":
                        self.convention = v
                        continue
                    if k == "history":
                        continue
                    self.nc_header_data.append("{}: {}".format(k, v))

                file.close()

        except Exception as e:
            self.nc_header_data.append("could not read header from netcdf: {}".format(e))

    @staticmethod
    def get_time():
        local_timezone = pytz.timezone('Europe/Berlin')

        local_time = datetime.now(local_timezone)

        return str(local_time.strftime('%Y-%m-%d %H:%M'))
