import os
import secrets
import string

from main.models import WmsColor
from django.utils.html import format_html


GDI_ADMIN_PERMISSION_GROUP = 'GDI-Users'


def get_user_groups(request):
    return request.user.groups.all().exclude(name=GDI_ADMIN_PERMISSION_GROUP)


def metadata_link(layer):
    if layer.geonetwork_uuid:
        link = os.environ.get('GEONETWORK_URL') + 'ger/catalog.search#/metadata/' + str(layer.geonetwork_uuid)
        return format_html("<a class='geonetwork-link' href='%s' target='_blank'>GeoNetwork %s</a>" % (link, layer.geonetwork_uuid))
    else:
        return '-'


def create_legend_map(legend, locale):

    prop = "name_en" if locale == "en" else "name_de"

    result = []
    for color in WmsColor.objects.filter(legend=legend).order_by('position'):
        result.append({
            "color": color.color,
            "label": getattr(color, prop),
            "quantity": int(color.upper_limit)
        })

    return result


def create_file_indentifier():
    chars = string.ascii_letters + string.digits
    result = ''

    for _ in range(32):
        result += secrets.choice(chars)

    return result
