
from main.models import BucketEvent


def get_bucket_name(event: BucketEvent) -> str:
    return event.event_data["Records"][0]["s3"]["bucket"]["name"]


def get_event_name(event: BucketEvent) -> str:
    return event.event_data["Records"][0]["eventName"]


def get_user(event: BucketEvent) -> str:
    return event.event_data["Records"][0]["userIdentity"]["principalId"]


def get_object_key(event: BucketEvent) -> str:
    return event.event_data["Records"][0]["s3"]["object"]["key"]


def get_filename(event: BucketEvent) -> str:
    pieces = get_object_key(event).split('%2F')
    return pieces[-1]


def extract_name_for_dataset(event: BucketEvent) -> str:
    """
    Returns the path without filename, e.g. 'green_up' oder 'monitor/precipitation/pre_last14d'
    :return:
    """
    name_parts = get_object_key(event).split('%2F')
    if len(name_parts) > 1:
        name_parts.pop()    # remove the last element which is the filename
        return "/".join(name_parts)
    else:
        return get_object_key(event)


def get_relative_path(event: BucketEvent) -> str:
    path = get_object_key(event)
    return path.replace('%2F', '/')


def is_netcdf(event: BucketEvent) -> bool:
    return get_object_key(event).endswith('.nc')


def is_geojson(event: BucketEvent) -> bool:
    return get_object_key(event).endswith('.geojson')


def is_geotiff(event: BucketEvent) -> bool:
    return get_object_key(event).endswith('.tif')


def is_create_event(event: BucketEvent) -> bool:
    return get_event_name(event) in ("s3:ObjectCreated:CompleteMultipartUpload", "s3:ObjectCreated:Put")


def is_delete_event(event: BucketEvent) -> bool:
    return get_event_name(event) == "s3:ObjectRemoved:Delete"
