import os
import s3fs
from minio import Minio


def get_s3_filesystem():

    params = {
        "endpoint_url": os.environ.get("MINIO_ENDPOINT")
    }

    region_name = os.environ.get("MINIO_REGION_NAME", None)
    if region_name:
        params["region_name"] = region_name

    return s3fs.S3FileSystem(
        client_kwargs=params,
        key=os.environ.get("MINIO_USERNAME"),
        secret=os.environ.get("MINIO_PASSWORD")
    )


def download_minio_file(bucket_name, object_key, output_file_path):
    minio_client = _get_minio_client()
    try:
        minio_client.fget_object(bucket_name, object_key, output_file_path)
        return True
    except:
        return False


def get_minio_download_link(bucket, object_key):
    minio_client = _get_minio_client()
    return minio_client.presigned_get_object(bucket, object_key)


def list_minio_folder(bucket, prefix):
    minio_client = _get_minio_client()
    return minio_client.list_objects(bucket, prefix)


def _get_minio_client():
    endpoint = os.environ.get("MINIO_ENDPOINT")
    if 'https://' in endpoint:
        host = endpoint.replace('https://', '')
        use_https = True
    else:
        host = endpoint.replace('http://', '')
        use_https = False

    return Minio(
        endpoint=host,
        access_key=os.environ.get("MINIO_USERNAME"),
        secret_key=os.environ.get("MINIO_PASSWORD"),
        secure=use_https
    )
