import os
import time

from main.lib.api.GeoserverApi import GeoServerApi
from main.lib.api.GeonetworkApi import GeonetworkApi


def get_data_dir():
    return "minio-files"


def get_geoserver_api():
    return GeoServerApi(
        os.environ.get("GEOSERVER_URL") + '/rest/',
        os.environ.get("GEOSERVER_USERNAME"),
        os.environ.get("GEOSERVER_PASSWORD")
    )


def get_geonetwork_api():
    return GeonetworkApi(
        os.environ.get("GEONETWORK_URL"),
        os.environ.get("GEONETWORK_USERNAME"),
        os.environ.get("GEONETWORK_PASSWORD")
    )


def sleep_by_defined_duration():
    time.sleep(int(os.environ.get("INTERVAL_SECONDS")))


def create_name_for_netcdf_workspace(path) -> str:
    """
    Returns the name which should be set for the coveragestore in GeoServer
    e.g. 'green_up' oder 'monitor_precipitation_pre_last14d'
    :param path:
    :return:
    """
    parts = path.split('/')
    return "_".join(parts)


def extract_coverage_name(path) -> str:
    parts = path.split('/')
    return parts[-1]


def get_coverage_name_by_file_path(file_path: str) -> str:
    """
    Returns the path without filename, e.g. 'green_up' oder 'monitor/precipitation/pre_last14d'
    :return:
    """
    name_parts = file_path.split('/')
    name_parts.pop(0)    # remove the first element which is the bucket
    if len(name_parts) > 1:
        name_parts.pop()    # remove the last element which is the filename
        return "/".join(name_parts)
    else:
        return file_path
