from django.core.management.base import BaseCommand

from owslib.wms import WebMapService

from main.models import Bucket, WmsLayer, WmsLayerLegend, WmsLegend
from main.lib.utils.worker_utils import *
from main.lib.legends.legend import create_sld_file


wms_url = os.environ.get("GEOSERVER_URL") + '/ows?service=wms&version=1.3.0&request=GetCapabilities'


class Command(BaseCommand):

    def handle(self, *args, **options):

        geoserver_api = get_geoserver_api()

        for legend in Legend.objects.all():
            sld = create_sld_file(legend, "de")
            geoserver_api.create_style(legend.name_de, sld)

            sld = create_sld_file(legend, "en")
            geoserver_api.create_style(legend.name_en, sld)

        for bucket in Bucket.objects.filter(connect_to_geoserver=True):
            geoserver_api.create_workspace(bucket.name)

        for layer in WmsLayer.objects.filter(file_record__bucket__connect_to_geoserver=True):

            file_record = layer.file_record

            if layer.file_path.endswith('.nc'):

                bucket_name = file_record.bucket.name
                absolute_path = '/{}/{}'.format(get_data_dir(), file_record.file_path)

                dataset_name = get_coverage_name_by_file_path(file_record.file_path)

                coverage_store = extract_coverage_name(dataset_name)
                workspace = bucket_name + "_" + create_name_for_netcdf_workspace(dataset_name)

                geoserver_api.create_netcdf_datastore(workspace, coverage_store, absolute_path)

            else:

                layer_name_parts = layer.layer_name.split(":")
                datastore_name = layer_name_parts[1]
                workspace = layer_name_parts[0]

                if file_record.file_path.endswith('*.tif'):
                    geoserver_api.create_mosaic_datastore(datastore_name, workspace)
                elif file_record.file_path.endswith('.tif'):
                    path = "file:///{}/{}".format(get_data_dir(), file_record.file_path)
                    geoserver_api.create_geotiff_datastore(datastore_name, workspace, path)

            layer_legends = WmsLayerLegend.objects.filter(layer=layer).order_by("position")

            for index, layer_legend in enumerate(layer_legends):
                style_name = layer_legend.legend.name_de
                if index == 0:
                    geoserver_api.add_style(style_name, layer.layer_name, True)
                else:
                    geoserver_api.add_style(style_name, layer.layer_name)

            geoserver_api.reset()

        print('done')
