import os
import requests
import json


from urllib.request import urlopen
from django.views.decorators.csrf import csrf_exempt

from django.http import HttpResponse, JsonResponse
from django.shortcuts import get_object_or_404

from .models import *


def _request_sta(url, sta_endpoint_id: int):
    endpoint = get_object_or_404(StaEndpoint, id=sta_endpoint_id)

    url = endpoint.base_url + url
    response = requests.get(url, auth=(endpoint.username, endpoint.password))

    return HttpResponse(response, content_type='application/json')


def proxy_sta_locations(request, sta_endpoint_id: int, obs_property_id: int = None):
    #url = url + '&$select=name,@iot.id&$expand=Locations($select=location),Datastreams($top=1;$orderBy=name%20asc;$expand=Observations($top=1;$orderBy=phenomenonTime%20desc))&$resultFormat=GeoJSON'

    url = "v1.1/Datastreams?"

    filter_params = _get_sta_filter_params(request, obs_property_id)

    endpoint = get_object_or_404(StaEndpoint, id=sta_endpoint_id)
    if endpoint.project:
        filter_params.append("substringof('{}',Thing/properties/projects)".format(endpoint.project))

    if len(filter_params) > 0:
        url = url + "$filter=" + " and ".join(filter_params) + "&"

    url = url + "$select=@iot.id&$expand=Thing($expand=Locations($select=location)),Observations($select=result;$top=1;$orderBy=phenomenonTime desc)&$resultFormat=GeoJSON"

    url = endpoint.base_url + url
    response = requests.get(url, auth=(endpoint.username, endpoint.password))

    return HttpResponse(response, content_type='application/json')


def _get_sta_filter_params(request, obs_property_id):

    filter_params = []

    if obs_property_id:
        param = "ObservedProperty/id eq {}".format(obs_property_id)
        filter_params.append(param)

    threshold = request.GET.get('threshold')
    if threshold:
        param = "Observations/result gt {}".format(threshold)
        filter_params.append(param)

    begin_date = request.GET.get('beginDate')
    if begin_date:
        param = "Observations/phenomenonTime gt {}T00:00:00%2B01:00".format(begin_date)
        filter_params.append(param)

    end_date = request.GET.get('endDate')
    if end_date:
        param = "Observations/phenomenonTime lt {}T00:00:00%2B01:00".format(end_date)
        filter_params.append(param)

    return filter_params


def proxy_sta_obs_properties(request, sta_endpoint_id: int):
    url = "v1.1/ObservedProperties"

    filter_params = []

    use_group = request.GET.get('useGroup')
    if use_group:
        filter_params.append("substringof('{}',properties/USE_GROUP)".format(use_group))

    endpoint = get_object_or_404(StaEndpoint, id=sta_endpoint_id)
    if endpoint.project:
        filter_params.append("substringof('{}',Datastreams/Thing/properties/projects)".format(endpoint.project))

    if len(filter_params) > 0:
        url = url + "?$filter=" + " and ".join(filter_params)

    url = endpoint.base_url + url
    response = requests.get(url, auth=(endpoint.username, endpoint.password))

    return HttpResponse(response, content_type='application/json')


def proxy_sta_all_datastreams(request, sta_endpoint_id: int, thing_id: int, obs_property_id: int):
    url = 'v1.1/Things({})/Datastreams?$filter=ObservedProperty/id eq {}'.format(thing_id, obs_property_id)
    return _request_sta(url, sta_endpoint_id)


def proxy_sta_obs_properties_by_thing(request, sta_endpoint_id: int, thing_id: int):
    url = 'v1.1/Datastreams?$select=id&$filter=Thing/id eq {}&$expand=ObservedProperty($orderBy=properties/name_de)'.format(thing_id)
    return _request_sta(url, sta_endpoint_id)


def proxy_sta_datastream(request, sta_endpoint_id: int, thing_id: int, datastream_id: int):
    url = 'v1.1/Things({})/Datastreams({})'.format(thing_id, datastream_id)
    url = url + '?$expand=ObservedProperty($select=properties/name_de),Observations($select=result,phenomenonTime;$orderby=phenomenonTime asc)'
    return _request_sta(url, sta_endpoint_id)


def get_sta_legend(request, locale: str, sta_legend_id: str):

    result = {'message': '', 'success': True}

    legend = get_object_or_404(StaLegend, id=sta_legend_id)
    record = model_to_dict(legend)
    record['colors'] = []

    for color in StaColor.objects.filter(legend=legend).order_by('position'):
        color_record = model_to_dict(color)
        color_record = set_text_by_locale(color_record, locale)
        record['colors'].append(color_record)

    result['legend'] = record

    return JsonResponse(result)
