
import csv
import json
import requests
import time

#FROST_URL = 'https://web.app.ufz.de/FROST-Server/v1.1/'
FROST_URL = 'http://localhost:8080/FROST-Server/v1.1/'


with open('.password') as f:
    password = f.read()
    auth = ('write', password)

# featureOfInterest = {
#   "name": "cheos",
#   "description": "Water Samples in Saxony",
#   "properties": {},
#   "encodingType": "application/geo+json",
#   "feature": {
#     "type": "Point",
#     "coordinates": [
#       12.10,
#       52.00
#     ]
#   }
# }
#
# x = requests.post(url, json=featureOfInterest, auth=auth)

location_id = 0
observed_property_id = 0
sensor_id = 0
datastream_id = 0

properties = {}
sensors = {}

things = {}

def extract_id(response_obj, route):
    content = response_obj.__dict__
    if 'Location' in content['headers']:
        resource_url = content['headers']['Location']
        obj_id = resource_url.replace(FROST_URL + route + "(", "")
        obj_id = obj_id.replace(")", "")
        return obj_id
    print("error")
    return False


STATION_ID_COL_NUM = 26
STATION_NAME_COL_NUM = 10
WATERBODY_COL_NUM = 12
LON_COL_NUM = 23
LAT_COL_NUM = 24

DTXSID_ID_COL_NUM = 17
CAS_NR_COL_NUM = 18
INCHI_KEY_COL_NUM = 16

NAME_DE_COL_NUM = 14
NAME_EN_COL_NUM = 15
USE_GROUP_COL_NUM = 13

UNIT_COL_NUM = 20

RESULT_COL_NUM = 4
TIMESTAMP_COL_NUM = 8
PREFIX_COL_NUM = 3


with open('231206_pivotData.csv', newline='') as csvfile:
    reader = csv.reader(csvfile, delimiter=',')
    headers = next(reader)
    for row in reader:

        if row[TIMESTAMP_COL_NUM][:4] == '':
            print("row skipped: " + row[TIMESTAMP_COL_NUM])
            continue

        station_idx = row[STATION_ID_COL_NUM].lower()

        if station_idx not in things.keys():
            thing = {
              "name": row[STATION_NAME_COL_NUM],
              "description": "test",
              "properties": {
                "station_id": row[STATION_ID_COL_NUM],
                "waterbody": row[WATERBODY_COL_NUM],
                "projects": ["SAX_ZP_DATA"]
              }
            }

            print(row[STATION_ID_COL_NUM] + " " + row[STATION_NAME_COL_NUM])

            things[station_idx] = {}

            response = requests.post("{}Things".format(FROST_URL), json=thing, auth=auth)
            thing_id = extract_id(response, "Things")

            location = {
              "name": row[STATION_NAME_COL_NUM],
              "description": row[STATION_NAME_COL_NUM],
              "properties": {
                "location_id": station_idx
              },
              "encodingType": "application/geo+json",
              "location": {
                "type": "Point",
                "coordinates": [float(row[LON_COL_NUM]), float(row[LAT_COL_NUM])]
              },
              "Things": [
                { "@iot.id": thing_id}
              ]
            }

            response = requests.post("{}Locations".format(FROST_URL), json=location, auth=auth)
            location_id = extract_id(response, "Location")

        property_idx = row[DTXSID_ID_COL_NUM]

        if property_idx not in properties.keys():

            property_idx = row[DTXSID_ID_COL_NUM]
            sensor_idx = row[DTXSID_ID_COL_NUM]

            observed_property = {
              "name": property_idx,
              "description": property_idx + " " + row[NAME_DE_COL_NUM],
              "properties": {
                "name_de": row[NAME_DE_COL_NUM],
                "name_en": row[NAME_EN_COL_NUM],
                "DTXSID": row[DTXSID_ID_COL_NUM],
                "CAS_NR": row[CAS_NR_COL_NUM],
                "INCHI_KEY": row[INCHI_KEY_COL_NUM],
                "USE_GROUP": row[USE_GROUP_COL_NUM]
              },
              "definition": "test"
            }

            response = requests.post("{}ObservedProperties".format(FROST_URL), json=observed_property, auth=auth)
            observed_property_id = extract_id(response, "ObservedProperties")
            properties[property_idx] = observed_property_id

        if property_idx not in things[station_idx].keys():

            sensor = {
              "name": "cheos " + property_idx,
              "description": "cheos",
              "properties": {},
              "encodingType": "application/pdf",
              "metadata": "test"
            }

            response = requests.post("{}Sensors".format(FROST_URL), json=sensor, auth=auth)
            sensor_id = extract_id(response, "Sensors")
            sensors[sensor_idx] = sensor_id

            datastream = {
              "name": property_idx,
              "description": "concentration of " + property_idx + " in the river",
              "observationType": "https://defs.opengis.net/vocprez/object?uri=http://www.opengis.net/def/observationType/OGC-OM/2.0/OM_Measurement",
              "unitOfMeasurement": {
                "name": "",
                "symbol": row[UNIT_COL_NUM],
                "definition": ""
              },
              "Thing": {"@iot.id": thing_id},
              "Sensor": {"@iot.id": int(sensors[sensor_idx])},
              "ObservedProperty": {"@iot.id": int(properties[property_idx])}
            }

            response = requests.post("{}Datastreams".format(FROST_URL), json=datastream, auth=auth)
            datastream_id = extract_id(response, "Datastreams")

            things[station_idx][property_idx] = datastream_id

        if row[RESULT_COL_NUM] == '':
            result = None
        else:
            result = float(row[RESULT_COL_NUM])

        observation = {
          "result": result,
          "phenomenonTime": row[TIMESTAMP_COL_NUM],
          "parameters": {
              "prefix": row[PREFIX_COL_NUM],
          },
          "Datastream": {"@iot.id": things[station_idx][property_idx]}
        }

        requests.post("{}Observations".format(FROST_URL), json=observation, auth=auth)
