import { reactive, ref, toRefs } from "vue"
import axios from "axios"
import { Area, ProjectInfo } from "@/types"
import {useRoute} from "vue-router";


function fetchData(url: string, result: any, responseProp: string) {

    const state = reactive({
        isLoading: false,
        error: null as any
    })

    const config = {
        headers: {
            "Content-type": "application/json charset=UTF-8"
        },
    }

    axios
        .get(url, config)
        .then((response) => {
            result.value = response.data.result[responseProp]
        })
        .catch((error) => {
            state.error = error
        })
        .finally(() => {
            state.isLoading = false
        })

    return {
        ...toRefs(state),
        result
    }
}


function setLocale(locale: string|undefined) {
    return (locale) ? locale : 'de'
}


function setProject(dynamicProjectName: string|undefined) {
    if (process.env.VUE_APP_PROJECT === 'gdi') {
        return dynamicProjectName
    }
    return process.env.VUE_APP_PROJECT
}


export function fetchProject(locale: string|undefined, route: string|undefined) {

    const url = process.env.VUE_APP_BACKEND_URL + 'project/' + setLocale(locale) + '/' + setProject(route)

    return fetchData(
        url,
        ref<ProjectInfo>(),
        'project_info'
    )
}


export function fetchAreas(locale: string|undefined, route: string|undefined) {

    const url = process.env.VUE_APP_BACKEND_URL + 'areas/' + setLocale(locale) + '/' + setProject(route)

    return fetchData(
        url,
        ref<Area[]>(),
        'areas'
    )
}


export function fetchProjects(locale: string|undefined) {

    const url = process.env.VUE_APP_BACKEND_URL + 'projects/' + setLocale(locale)

    return fetchData(
        url,
        ref<ProjectInfo[]>(),
        'projects'
    )
}
