import {PlotlyTimeSeries} from "@/types";


const seasonalDates = [
    { 'month': 3, 'de': 'Frühling', 'en': 'Spring' },
    { 'month': 6, 'de': 'Sommer', 'en': 'Summer' },
    { 'month': 9, 'de': 'Herbst', 'en': 'Autumn' }
]


export function convertTime(value: string, locale: 'de'|'en', timeFormat: string|null = null) {

    if (value === '') {
        return ''
    }

    const date = new Date(value)

    if (timeFormat === 'period') {
        return getPeriodByDate(value)
    }
    if (timeFormat === 'year') {
        return date.getFullYear() + ''
    }
    if (timeFormat === 'month') {
        return date.toLocaleDateString('de-DE', { year: 'numeric', month: '2-digit' })
    }
    if (timeFormat === 'season') {
        return getSeasonalDate(value, locale)
    }
    return date.toLocaleDateString('de-DE', { year: 'numeric', month: '2-digit', day: '2-digit' })
}


export function getSeasonalDate(timeStep: string, locale: 'de'|'en') {
    let result = timeStep

    const date = new Date(timeStep)

    for (const season of seasonalDates) {
        if (date.getMonth() === season.month) {
            result = season[locale] + ' ' + date.getFullYear()
        }
    }
    return result
}

export function getPeriodByDate(timeStep: string) {
    const date = new Date(timeStep)
    const year = date.getFullYear()
    return (year - 14) + '-' + (year + 15)
}

export function getSeasonalDates(timeseries: PlotlyTimeSeries, locale: 'de'|'en') {
    const tickvals = []
    const ticktexts = []

    for (const timeStep of timeseries.x) {
        tickvals.push(timeStep)
        ticktexts.push(getSeasonalDate(timeStep, locale))
    }

    return {
      tickmode: "array",
      tickvals: tickvals,
      ticktext: ticktexts,
      tickangle: 45
    }
}

export function getPeriodDates(timeseries: PlotlyTimeSeries) {
    const tickvals = []
    const ticktexts = []

    for (const timeStep of timeseries.x) {
        tickvals.push(timeStep)
        ticktexts.push(getPeriodByDate(timeStep))
    }

    return {
      tickmode: "array",
      tickvals: tickvals,
      ticktext: ticktexts
    }
}


export function isValidDateFormat(dateInput: string) {

    console.log(dateInput)
    if (dateInput == '' || dateInput == undefined) {
        return true
    }
    return dateInput.match(/^\d{4}[\/\-](0?[1-9]|1[012])[\/\-](0?[1-9]|[12][0-9]|3[01])$/);
}