import {LegendRecord, WMSLayer} from "@/types";


const coordFormat = new Intl.NumberFormat('de-DE', {
    minimumFractionDigits: 4,
    maximumFractionDigits: 4
});


export function getLastTimeStepIfExists(layer: WMSLayer) {
    if (layer.time_steps.length > 0) {
        return layer.time_steps.slice(-1)[0]
    }
    console.log('not found for: ' + layer.name)
    return ''
}

export function setPageHeight() {
    const style = getComputedStyle(document.body);
    const headerHeight = style.getPropertyValue('--header-height') as string

    const contentHeight = `calc(${window.innerHeight}px - ${headerHeight})`
    document.body.style.height = contentHeight;

    ["map", "sidenav", "sidenavModal"].forEach(function (selector) {
        const element = document.getElementById(selector)
        if (element) {
            element.style.height = contentHeight
        }
    })
}

export function round4(num: number) {
    return coordFormat.format(num)
}

export function getTextValue(layer: WMSLayer, value: number)  {

    let result = ''

    const style = layer.styles[0]

    if (layer.legends_to_map) {

        const legend = layer.legends_to_map[style]
        if (legend) {
            legend.forEach(function (record: LegendRecord) {
                if (record.quantity == value) {
                    result = record.label
                }
            })
        }
    }
    return result
}